@@ -29,6 +29,9 @@ modeldata<-function(fit,newdata=NULL,crrmol=FALSE){
     fit2$model=fit2$model[,-1]
     data<-fit2$model
   }
+  if ('scixgboot' %in% class(fit)) {
+    data<-fit[["data"]]
+  }
   data
 }
 
@@ -45,6 +48,12 @@ model.y<-function(fit){
   if ('ksvm' %in% class(fit)){
     modely<-all.vars(fit@terms)[c(1)]
   }
+  if ('svm' %in% class(fit)){
+    modely<-all.vars(fit$terms)[c(1)]
+  }
+  if ('scixgboot' %in% class(fit)) {
+    modely<-fit[["y"]]
+  }
   modely
 }
 model.x<-function(fit){
@@ -60,5 +69,11 @@ model.x<-function(fit){
   if ('ksvm' %in% class(fit)){
     modelx<-all.vars(fit@terms)[-c(1)]
   }
+  if ('svm' %in% class(fit)){
+    modelx<-all.vars(fit$terms)[-c(1)]
+  }
+  if ('scixgboot' %in% class(fit)) {
+    modelx<-fit[["x"]]
+  }
   modelx
 }
